@@ -1,4 +1,4 @@
-//  $Id: f_cisco.cc 1.10.1.5.1.46.2.1 Thu, 14 Oct 1999 11:49:55 -0700 cengiz $
+//  $Id: f_cisco.cc 1.10.1.5.1.50 Thu, 20 Apr 2000 20:44:19 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -203,17 +203,17 @@ ListOf2Ints *CiscoConfig::printPrefixList(SetOfPrefix& nets) {
    // print martians
    char *martians[] = { 
       "0.0.0.0/0 ge 32",
-      "127.0.0.0/8 ge 8",
-      "10.0.0.0/8 ge 8",
-      "172.16.0.0/12 ge 12",
-      "192.168.0.0/16 ge 16",
-      "192.0.2.0/24 ge 24",
-      "128.0.0.0/16 ge 16",
-      "191.255.0.0/16 ge 16",
-      "192.0.0.0/24 ge 24",
-      "223.255.255.0/24 ge 24",
-      "224.0.0.0/3 ge 3",
-      "169.254.0.0/16 ge 16",
+      "127.0.0.0/8 le 32",
+      "10.0.0.0/8 le 32",
+      "172.16.0.0/12 le 32",
+      "192.168.0.0/16 le 32",
+      "192.0.2.0/24 le 32",
+      "128.0.0.0/16 le 32",
+      "191.255.0.0/16 le 32",
+      "192.0.0.0/24 le 32",
+      "223.255.255.0/24 le 32",
+      "224.0.0.0/3 le 32",
+      "169.254.0.0/16 le 32",
       NULL
    };
 
@@ -725,6 +725,17 @@ void CiscoConfig::printActions(ostream &os, PolicyActionList *actions) {
 	 continue;
       }
 
+      if (actn->rp_attr == dctn_rp_nhop) {
+	 if (actn->rp_method == dctn_rp_nhop_set) {
+	    char buffer[32];
+	    IPAddr *ip = ((ItemIPV4 *) actn->args->head())->ipv4;
+	    ip->get_text(buffer);
+	    os << " set ip next-hop " << buffer << "\n";
+	 } else 
+	    UNIMPLEMENTED_METHOD;
+	 continue;
+      }
+
       if (actn->rp_attr == dctn_rp_dpa) {
 	 if (actn->rp_method == dctn_rp_dpa_set) {
 	    int dpa = ((ItemINT *) actn->args->head())->i;
@@ -861,7 +872,7 @@ bool CiscoConfig::printNeighbor(int import,
    if (! printRouteMap)
       return false;
 
-   char *direction = (import == IMPORT) ? "in" : "out";
+   const char *direction = (import == IMPORT) ? "in" : "out";
 
    if (!routeMapGenerated && (!import || ! prefixListGenerated)) {
       // yes we are conciously printing an "not any" policy
@@ -888,7 +899,7 @@ bool CiscoConfig::printNeighbor(int import,
    return true;
 }
 
-void CiscoConfig::export(ASt asno, IPAddr *addr, 
+void CiscoConfig::exportP(ASt asno, IPAddr *addr, 
 			 ASt peerAS, IPAddr *peer_addr) {
 
    // Made asno part of the map name if it's not changed by users
@@ -924,7 +935,7 @@ void CiscoConfig::export(ASt asno, IPAddr *addr,
    prefixListGenerated = false;
 }
 
-void CiscoConfig::import(ASt asno, IPAddr *addr, 
+void CiscoConfig::importP(ASt asno, IPAddr *addr, 
 			 ASt peerAS, IPAddr *peer_addr) {
 
    // Made asno part of the map name if it's not changed by users
